'''
    db-patch applies static and dynamic patches to databases using ODBC or native
    connectors.
    Copyright (C) 2012, 2013  Miguel A. Martinez Pinedo

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
'''


import dbpatch.options
import dbpatch.connection.odbc as odbc


class SQLiteQueryBuilder(odbc.OdbcQueryBuilder):

    NAME = 'sqlite'
    
    def is_single_database_engine(self):
        """
        Determine if the database engine support a single database.
        By example SQLite only support a single database, on other
        hand MySQL support several databases.

        Return true if the engine only supports a single database,
        false in other case (by default return false).
        """
        return True

    def get_connection_string(self, db_name=None):
        if self._options.get_option(dbpatch.options.ODBC_FULL_CONN):
            return self._options.get_option(dbpatch.options.ODBC_FULL_CONN)

        driver = self._options.get_option(dbpatch.options.ODBC_DRIVER)
        return 'DRIVER={%s};DATABASE=%s;' % (driver, db_name)


def register():
    odbc.OdbcQueryBuilderFactory.register(SQLiteQueryBuilder)

