'''
    db-patch applies static and dynamic patches to databases using ODBC or native
    connectors.
    Copyright (C) 2012, 2013  Miguel A. Martinez Pinedo

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
'''


import time

from dbpatch.singleton import Singleton


class Context(object):

    __metaclass__= Singleton

    ODBC_CONN  = 'ODBC'
    DBAPI_CONN = 'DBAPI'

    def __init__(self):
        self._connection_type = None
        self._options    = {}
        self._init_time  = time.time()
        self._end_time   = time.time()
        self._current_db = None
        self._current_patch = None

    def __repr__(self):
        return 'Context. Conn[%s]. Init[%s]. CurrentDb[%s]. ' \
            'CurrentPatch[%s]' % (self._connection_type,
                                  self._init_time,
                                  self._current_db,
                                  self._current_patch)

    def __get_init_time(self):
        return self._init_time

    def __get_end_time(self):
        return self._end_time

    def set_end_time(self):
        self._end_time = time.time()

    def __get_conn_type(self):
        return self._connection_type

    def set_odbc_conn_type(self):
        self._connection_type = Context.ODBC_CONN

    def set_dbapi_conn_type(self):
        self._connection_type = Context.DBAPI_CONN

    def using_odbc_conn(self):
        return self._connection_type == Context.ODBC_CONN

    def using_dbapi_conn(self):
        return self._connection_type == Context.DBAPI_CONN

    def __get_current_db(self):
        return self._current_db

    def __set_current_db(self, current_db):
        self._current_db = current_db

    def __get_options(self):
        return self._options

    def __set_options(self, options):
        self._options = options

    def __get_current_patch(self):
        return self._current_patch

    def __set_current_patch(self, current_patch):
        self._current_patch = current_patch

    conn_type  = property(fget=__get_conn_type)
    init_time  = property(fget=__get_init_time)
    end_time   = property(fget=__get_end_time)
    options    = property(fget=__get_options, fset=__set_options)
    current_db = property(fget=__get_current_db, fset=__set_current_db)
    current_patch = property(fget=__get_current_patch,
                             fset=__set_current_patch)
