'''
    db-patch applies static and dynamic patches to databases using ODBC or native
    connectors.
    Copyright (C) 2012, 2013  Miguel A. Martinez Pinedo

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
'''


import logging
import re
from dbpatch.log import LogFactory

class DbFilter(object):

    def __init__(self, all_dbs, exclude, include, only_databases):
        self._log = LogFactory().get_logger(DbFilter.__name__)
        self._dbs = all_dbs
        self._exclude = exclude
        self._include = include
        self._only_databases = only_databases

    def _filter_only_databases(self):
        dbs = filter(lambda db : db in self._only_databases, self._dbs)
        self._log.info('Using the databases %s ' % str(dbs))
        return dbs

    def _filter_exclude(self):
        pattern = re.compile(self._exclude)
        dbs = filter(lambda db : pattern.match(db)==None, self._dbs)
        self._log.info('Using the databases %s' % str(dbs))
        return dbs

    def _filter_include(self):
        pattern = re.compile(self._include)
        dbs = filter(lambda db : pattern.match(db)!=None, self._dbs)
        self._log.info('Using the databases %s' % str(dbs))
        return dbs

    def apply_filter(self):
        if self._only_databases:
            return self._filter_only_databases()

        if self._exclude:
            return self._filter_exclude()

        if self._include:
            return self._filter_include()

        self._log.info('Using the databases %s' % str(self._dbs))
        return self._dbs
