'''
    db-patch applies static and dynamic patches to databases using ODBC or native
    connectors.
    Copyright (C) 2012, 2013  Miguel A. Martinez Pinedo

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
'''


import dbpatch.options
import dbpatch.loader
import dbpatch.patch


class PythonPatch(dbpatch.patch.Patch):

    def __init__(self):
        dbpatch.patch.Patch.__init__(self)

    def execute(self, db_name):
        return True


class PythonPatchExecutor(dbpatch.patch.Patch):

    EXTENSION = 'py'
    PATCH_CLASS = 'dbpatch.patch.python.PythonPatch'

    def __init__(self):
        dbpatch.patch.Patch.__init__(self)
        self._patch = None
        self.__load_module()

    def __load_module(self):
        patch_file  = self._options.get_option(dbpatch.options.PATCH_FILE)
        module_name = patch_file.split('.')[0]
        self._patch = dbpatch.loader.new_class_child_of(
            module_name,
            PythonPatchExecutor.PATCH_CLASS)

    def pre_execute(self):
        return self._patch.pre_execute()

    def before_database(self, db_name):
        self._patch.before_database(db_name)

    def execute(self, db_name):
        return self._patch.execute(db_name)

    def after_database(self, db_name):
        self._patch.after_database(db_name)

    def post_execute(self):
        return self._patch.post_execute()



def register():
    dbpatch.patch.PatchFactory.register(PythonPatchExecutor)
