'''
    db-patch applies static and dynamic patches to databases using ODBC or native
    connectors.
    Copyright (C) 2012, 2013  Miguel A. Martinez Pinedo

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
'''


import dbpatch.options
from dbpatch.log import LogFactory
import dbpatch.patch


class RawPatch(dbpatch.patch.Patch):
    '''
    Execute all the content of a file in a single query. Useful by
    example for PL SQL scripts. Be careful, you must introduce
    a single query.

    The keyword 'mydb' will be replaced by each database name
    '''

    EXTENSION = 'raw'

    def __init__(self):
        dbpatch.patch.Patch.__init__(self)
        self._log  = LogFactory().get_logger(RawPatch.__name__)
        patch_file = self._options.get_option(dbpatch.options.PATCH_FILE)
        self._queries = open(patch_file, 'r').read()


    def execute(self, db_name):
        connection = self.connect_to(db_name)
        queries = self._queries.replace('mydb', db_name)
        statement = self.create_statement(queries)
        status = statement.execute()
        if not status:
            return False

        return True


def register():
    dbpatch.patch.PatchFactory.register(RawPatch)
